.. Note: place names and roles of the people who contribute to this package
   in this file, one to a line, like so:

- Peter Mathis (petschki)
- Joscha Krutzki (joka)
- Harald Frießnegger (fRiSi)
- Martijn Zweistra (themask96)
- Daniel Widerin (saily)
- Wolfgang Thomas (pysailor)
- Héctor Velarde (hvelarde)
- Tom Gross (tom_gross)
- Jens W. Klein (jensens)
- Benjamin Stefaner (benniboy)

Credits
-------

The basic concept of ``plone.app.imagecropping`` has already been implemented in `Yiorgis's branch of plone.app.imaging`_

.. _`Yiorgis's branch of plone.app.imaging`: https://github.com/plone/plone.app.imaging/tree/ggozad-cropping

Source Code
-----------

If you want to help with the development (improvement, update, bug-fixing, ...)
of ``plone.app.imagecropping`` this is a great idea!

The code is located in the
`github collective <https://github.com/collective/plone.app.imagecropping>`_.

You can clone it and send a pull request or `get access to the github-collective
<http://collective.github.com/>`_ and work directly on the project.